@@ -21,9 +21,9 @@ import ngs_plumbing.fasta as fasta
 class FastaTestCase(unittest.TestCase):
 
     def setUp(self):
-        data = ('> S1', b'ATACGCGGCT'+b'GATCGTAGCG'+b'GATCGTAGCG'+'AA',
-                '> S2', b'AGACGCGGCT'+b'GATCGTAGCG'+b'GATCGTAGCG'+'CC',
-                b'ACACGCGGCT'+b'GATCGTAGCG'+b'AGACGCGGCT'+'GG')
+        data = (b'> S1', b'ATACGCGGCT'+b'GATCGTAGCG'+b'GATCGTAGCG'+b'AA',
+                b'> S2', b'AGACGCGGCT'+b'GATCGTAGCG'+b'GATCGTAGCG'+b'CC',
+                b'ACACGCGGCT'+b'GATCGTAGCG'+b'AGACGCGGCT'+b'GG')
         self._data = data
 
     def test_read_fasta(self):
@@ -35,7 +35,7 @@ class FastaTestCase(unittest.TestCase):
         self.assertEquals(data[0], res[0].header)
         self.assertEquals(data[1], res[0].sequence)
         self.assertEquals(data[2], res[1].header)
-        self.assertEquals(''.join(data[3:]), res[1].sequence)
+        self.assertEquals(b''.join(data[3:]), res[1].sequence)
 
     def test_read_fastab(self):
         data = tuple(fasta.read_fasta(self._data))
@@ -47,7 +47,7 @@ class FastaTestCase(unittest.TestCase):
         stream = io.BytesIO(b)
         stream.flush()
         stream.seek(0)
-        res = fasta.read_fastab(stream).next()
+        res = next(fasta.read_fastab(stream))
         self.assertEqual(data[1].header, res.header)
         self.assertEqual(len(bitpacked), len(res.sequence))
         for i in range(len(bitpacked)):
@@ -59,7 +59,7 @@ class FastaTestCase(unittest.TestCase):
         fasta.tofastab(data[1], stream)
         stream.flush()
         stream.seek(0)
-        res = fasta.read_fastab(stream).next()
+        res = next(fasta.read_fastab(stream))
         self.assertEqual(data[1].header, res.header)
         bitpacked = PackedDNABytes(data[1].sequence)
         self.assertEqual(len(bitpacked), len(res.sequence))
