@@ -1,7 +1,7 @@
 # This file is part of ngs_plumbing.
 
 # ngs_plumbing is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
@@ -10,7 +10,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with ngs_plumbing.  If not, see <http://www.gnu.org/licenses/>.
 
 # Copyright 2012 Laurent Gautier
@@ -321,7 +321,7 @@ class XSQInfo(OrderedDict):
         res = OrderedDict()
         try:
             mtd = xsqfile.run_metadata
-        except KeyError, ke:
+        except KeyError as ke:
             mtd = None
  
         for at, fun in cls.__ats:
@@ -369,7 +369,7 @@ class XSQTagDetails(h5py._hl.group.Group):
 def seqid_template(f, flowcell, tile):
     try:
         serial = f.run_metadata.attrs['InstrumentSerial'][0]
-    except (AttributeError, KeyError), ke:
+    except (AttributeError, KeyError) as ke:
         serial = 'UnknownSerial'
         
     seq_id = '@%s:%s:%s' %(serial, flowcell, tile) + ':%i:%i#0'
@@ -443,8 +443,6 @@ def _xsqvalues_to_csfasta(xsqvalues, xyloc, buf_cs, buf_qual, seq_id, prefix):
     bases_i = range(xsqvalues.shape[1]-1)
     for row_i in xrange(xsqvalues.shape[0]): 
         seq, qual = colourqual_frombuffer(xsqvalues[row_i])
-        # turn integers to their ASCII representations
-        seq = bytearray_addint(seq, 48)
         x,y = xyloc[row_i]
         this_seq_id = seq_id % (x,y)
         buf_cs.writelines((this_seq_id, '\n', prefix, seq, '\n'))
@@ -537,7 +535,7 @@ def automagic_fastq(filename, path_out = '.', fragment = None,
     for i, lib_name in enumerate(library_names):
         out.write('%s (%i / %i)\n' %(lib_name, i+1, len(library_names)))
         out.flush()
-        lib = f.library(lib_name)
+        lib = f.library(lib_name, unassigned = want_unassigned)
         if fragment is None:
             fragment_list = tuple(lib.fragments())
         else:
